#
# spec file for package guile-json
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           guile-json
Version:        4.7.3
Release:        1.5
Summary:        JSON module for Guile
License:        GPL-3.0-or-later
Group:          Development/Libraries/Other
URL:            https://savannah.nongnu.org/projects/guile-json/
Source0:        http://download.savannah.gnu.org/releases/guile-json/%{name}-%{version}.tar.gz
Source1:        http://download.savannah.gnu.org/releases/guile-json/%{name}-%{version}.tar.gz.sig
Source2:        https://savannah.nongnu.org/people/viewgpg.php?user_id=11331#/%{name}.keyring
BuildRequires:  guile-devel >= 2.0.10
Requires:       guile >= 2.0.10
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Guile-json is JSON module for Guile. It supports parsing and building
JSON documents according to the http:://json.org specification. These
are the main features:

- Strictly complies to http://json.org specification.
- Build JSON documents programmatically via macros.
- Unicode support for strings.
- Allows JSON pretty printing.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%check
make %{?_smp_mflags} check

%install
make install %{_smp_mflags} DESTDIR=%{buildroot}

%files
%defattr(-,root,root,-)
%license COPYING
%doc AUTHORS NEWS README
%{_datadir}/guile*
%{_libdir}/guile*

%changelog
* Sun Jun 18 2023 Jonathan Brielmaier <jbrielmaier@opensuse.org>
- Update to 4.7.3:
  * Fix a regression introduced in 4.7.1 where (json->RECORD) was not working
    with nested fields.
* Sat Sep 17 2022 Jonathan Brielmaier <jbrielmaier@opensuse.org>
- Update to 4.7.2:
  * add support for JSON Text Sequences and Concatenated JSON
  * allow returning ordered JSON objects key/value pairs by using
    the keyword argument #:ordered
  * allow nested records in other records
- remove rpmlintrc as no longer required
* Wed May 12 2021 Jonathan Brielmaier <jbrielmaier@opensuse.org>
- Update to 4.5.2:
  * Add missing modules to record.scm.
  * Allow false values in JSON mappings.
  * Introduce (define-json-type)
  * Fixed a few parsing issues from JSON Parsing Test Suite
* Fri Nov  6 2020 Jonathan Brielmaier <jbrielmaier@opensuse.org>
- Update to 4.4.0:
  * Breaking changes:
  * * (scm->json) and (scm->json-string) #:espace keyword argument has been
    renamed to #:solidus.
  * * JSON null now defaults to the null symbol. This can be changed in all
    public functions with the #:null keyword argument.
  * Various bug fixes
  * New features
* Mon Jan 13 2020 Jonathan Brielmaier <jbrielmaier@suse.de>
- Make guile-json-rpmlintrc compatible with Guile 3.0
* Mon Sep 16 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 3.2.0:
  * Fix writing empty objects to JSON (e.g. (scm->json-string '())).
  * Complex numbers, inf and nan are not allowed anymore as valid numbers
    when building JSON.
* Mon Jul 22 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 3.1.0 (changes since 1.2.0):
  * Breaking compability to version 1.x and 2.x
  * JSON objects are now defined as alists (instead of hash tables)
    and JSON arrays are now defined as vectors (instead of lists).
    Both of these changes are mainly to use types that have read syntax.
    This will simplify things for the user when defining JSON objects
    which is probably the most common case.
  * Added unit tests.
  * scm->json and scm->json-string now support an additional key
    argument #:unicode.
- filter more messages in rpmlintrc
- require guile >= 2.0.10 because it implements srfi-43
- run test suite
* Fri Aug 24 2018 jbrielmaier@suse.de
- bump to 1.2.0
  changes since 1.0.1
  - License only GPLv3+
  - install .go file to %%(libdir)/guile
- add guile as runtime dependency to avoid "compiling" when using
  (json) for the first time
- needs guile-devel to avoid build failure
* Tue May 29 2018 jbrielmaier@suse.de
- bump to 1.0.1
  changes since 0.6.0
  - now under GPLv3+ and LGPLv3+
  - support 4-byte unicode characters
  - fix smaller issues
* Mon May  7 2018 sleep_walker@opensuse.org
- add guile-json-rpmlintrc file to suppress failures
* Fri Mar  9 2018 sleep_walker@opensuse.org
- mov license file from %%doc to %%license
* Thu Feb 15 2018 sleep_walker@opensuse.org
- bump to 0.6.0
  changes since 0.5.0
  - Deprecate json macro in favor of scheme data types.
* Thu Feb 15 2018 sleep_walker@opensuse.org
- make package not noarch
* Fri Jul 22 2016 sleep_walker@opensuse.org
- bump to 0.5.0
  changes since 0.4.0:
  * Allow converting simple alists to json
    e.g.: (scm->json-string '((a . 1) (b . 2))))
* Sun Nov  8 2015 astieger@suse.com
- add source URLs, keyring and verify source signatures
- license is LGPL-3.0+ as per code headers
- package license file
* Fri Nov  6 2015 sleep_walker@opensuse.org
- fix RPM group
- add tarball signature as RPM Source
* Fri Nov  6 2015 sleep_walker@opensuse.org
- require guile 2.0+ to prevent build failures
* Thu Nov  5 2015 sleep_walker@opensuse.org
- let there be guile-json
